@@ -14,7 +14,6 @@ from libdyson import (
     DEVICE_TYPE_PURE_HOT_COOL,
     DEVICE_TYPE_PURE_HOT_COOL_NEW,
     DEVICE_TYPE_PURE_HOT_COOL_LINK,
-    DEVICE_TYPE_PURE_HOT_COOL_LINK_NEW,
     DEVICE_TYPE_PURE_HUMIDIFY_COOL,
     Dyson360Eye,
     Dyson360Heurist,
@@ -41,7 +40,6 @@ from . import CREDENTIAL, SERIAL
         (DEVICE_TYPE_PURE_COOL_2021, DysonPureCool),
         (DEVICE_TYPE_PURE_COOL_DESK, DysonPureCool),
         (DEVICE_TYPE_PURE_HOT_COOL_LINK, DysonPureHotCoolLink),
-        (DEVICE_TYPE_PURE_HOT_COOL_LINK_NEW, DysonPureHotCoolLink),
         (DEVICE_TYPE_PURE_HOT_COOL, DysonPureHotCool),
         (DEVICE_TYPE_PURE_HOT_COOL_NEW, DysonPureHotCool),
         (DEVICE_TYPE_PURE_HUMIDIFY_COOL, DysonPureHumidifyCool),
